# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .apt_artifact import (
    AptArtifact,
    ImportAptArtifactsErrorInfo,
    ImportAptArtifactsGcsSource,
    ImportAptArtifactsMetadata,
    ImportAptArtifactsRequest,
    ImportAptArtifactsResponse,
)
from .file import File, GetFileRequest, Hash, ListFilesRequest, ListFilesResponse
from .package import (
    DeletePackageRequest,
    GetPackageRequest,
    ListPackagesRequest,
    ListPackagesResponse,
    Package,
)
from .repository import (
    CreateRepositoryRequest,
    DeleteRepositoryRequest,
    GetRepositoryRequest,
    ListRepositoriesRequest,
    ListRepositoriesResponse,
    Repository,
    UpdateRepositoryRequest,
)
from .service import OperationMetadata
from .settings import (
    GetProjectSettingsRequest,
    ProjectSettings,
    UpdateProjectSettingsRequest,
)
from .tag import (
    CreateTagRequest,
    DeleteTagRequest,
    GetTagRequest,
    ListTagsRequest,
    ListTagsResponse,
    Tag,
    UpdateTagRequest,
)
from .version import (
    DeleteVersionRequest,
    GetVersionRequest,
    ListVersionsRequest,
    ListVersionsResponse,
    Version,
    VersionView,
)
from .yum_artifact import (
    ImportYumArtifactsErrorInfo,
    ImportYumArtifactsGcsSource,
    ImportYumArtifactsMetadata,
    ImportYumArtifactsRequest,
    ImportYumArtifactsResponse,
    YumArtifact,
)

__all__ = (
    "AptArtifact",
    "ImportAptArtifactsErrorInfo",
    "ImportAptArtifactsGcsSource",
    "ImportAptArtifactsMetadata",
    "ImportAptArtifactsRequest",
    "ImportAptArtifactsResponse",
    "File",
    "GetFileRequest",
    "Hash",
    "ListFilesRequest",
    "ListFilesResponse",
    "DeletePackageRequest",
    "GetPackageRequest",
    "ListPackagesRequest",
    "ListPackagesResponse",
    "Package",
    "CreateRepositoryRequest",
    "DeleteRepositoryRequest",
    "GetRepositoryRequest",
    "ListRepositoriesRequest",
    "ListRepositoriesResponse",
    "Repository",
    "UpdateRepositoryRequest",
    "OperationMetadata",
    "GetProjectSettingsRequest",
    "ProjectSettings",
    "UpdateProjectSettingsRequest",
    "CreateTagRequest",
    "DeleteTagRequest",
    "GetTagRequest",
    "ListTagsRequest",
    "ListTagsResponse",
    "Tag",
    "UpdateTagRequest",
    "DeleteVersionRequest",
    "GetVersionRequest",
    "ListVersionsRequest",
    "ListVersionsResponse",
    "Version",
    "VersionView",
    "ImportYumArtifactsErrorInfo",
    "ImportYumArtifactsGcsSource",
    "ImportYumArtifactsMetadata",
    "ImportYumArtifactsRequest",
    "ImportYumArtifactsResponse",
    "YumArtifact",
)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.type import expr_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.devtools.artifactregistry.v1",
    manifest={
        "Rule",
        "ListRulesRequest",
        "ListRulesResponse",
        "GetRuleRequest",
        "CreateRuleRequest",
        "UpdateRuleRequest",
        "DeleteRuleRequest",
    },
)


class Rule(proto.Message):
    r"""A rule defines the deny or allow action of the operation it
    applies to and the conditions required for the rule to apply.
    You can set one rule for an entire repository and one rule for
    each package within.

    Attributes:
        name (str):
            The name of the rule, for example:
            ``projects/p1/locations/us-central1/repositories/repo1/rules/rule1``.
        action (google.cloud.artifactregistry_v1.types.Rule.Action):
            The action this rule takes.
        operation (google.cloud.artifactregistry_v1.types.Rule.Operation):

        condition (google.type.expr_pb2.Expr):
            Optional. A CEL expression for conditions
            that must be met in order for the rule to apply.
            If not provided, the rule matches all objects.
        package_id (str):
            The package ID the rule applies to.
            If empty, this rule applies to all packages
            inside the repository.
    """

    class Action(proto.Enum):
        r"""Defines the action of the rule.

        Values:
            ACTION_UNSPECIFIED (0):
                Action not specified.
            ALLOW (1):
                Allow the operation.
            DENY (2):
                Deny the operation.
        """
        ACTION_UNSPECIFIED = 0
        ALLOW = 1
        DENY = 2

    class Operation(proto.Enum):
        r"""The operation the rule applies to.

        Values:
            OPERATION_UNSPECIFIED (0):
                Operation not specified.
            DOWNLOAD (1):
                Download operation.
        """
        OPERATION_UNSPECIFIED = 0
        DOWNLOAD = 1

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    action: Action = proto.Field(
        proto.ENUM,
        number=2,
        enum=Action,
    )
    operation: Operation = proto.Field(
        proto.ENUM,
        number=3,
        enum=Operation,
    )
    condition: expr_pb2.Expr = proto.Field(
        proto.MESSAGE,
        number=4,
        message=expr_pb2.Expr,
    )
    package_id: str = proto.Field(
        proto.STRING,
        number=5,
    )


class ListRulesRequest(proto.Message):
    r"""The request to list rules.

    Attributes:
        parent (str):
            Required. The name of the parent repository whose rules will
            be listed. For example:
            ``projects/p1/locations/us-central1/repositories/repo1``.
        page_size (int):
            The maximum number of rules to return.
            Maximum page size is 1,000.
        page_token (str):
            The next_page_token value returned from a previous list
            request, if any.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListRulesResponse(proto.Message):
    r"""The response from listing rules.

    Attributes:
        rules (MutableSequence[google.cloud.artifactregistry_v1.types.Rule]):
            The rules returned.
        next_page_token (str):
            The token to retrieve the next page of rules,
            or empty if there are no more rules to return.
    """

    @property
    def raw_page(self):
        return self

    rules: MutableSequence["Rule"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Rule",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetRuleRequest(proto.Message):
    r"""The request to retrieve a rule.

    Attributes:
        name (str):
            Required. The name of the rule to retrieve.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CreateRuleRequest(proto.Message):
    r"""The request to create a new rule.

    Attributes:
        parent (str):
            Required. The name of the parent resource
            where the rule will be created.
        rule_id (str):
            The rule id to use for this repository.
        rule (google.cloud.artifactregistry_v1.types.Rule):
            The rule to be created.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    rule_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    rule: "Rule" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="Rule",
    )


class UpdateRuleRequest(proto.Message):
    r"""The request to update a rule.

    Attributes:
        rule (google.cloud.artifactregistry_v1.types.Rule):
            The rule that replaces the resource on the
            server.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The update mask applies to the resource. For the
            ``FieldMask`` definition, see
            https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
    """

    rule: "Rule" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Rule",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteRuleRequest(proto.Message):
    r"""The request to delete a rule.

    Attributes:
        name (str):
            Required. The name of the rule to delete.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.devtools.artifactregistry.v1",
    manifest={
        "VPCSCConfig",
        "GetVPCSCConfigRequest",
        "UpdateVPCSCConfigRequest",
    },
)


class VPCSCConfig(proto.Message):
    r"""The Artifact Registry VPC SC config that apply to a Project.

    Attributes:
        name (str):
            The name of the project's VPC SC Config.

            Always of the form:

            projects/{projectID}/locations/{location}/vpcscConfig

            In update request: never set
            In response: always set
        vpcsc_policy (google.cloud.artifactregistry_v1.types.VPCSCConfig.VPCSCPolicy):
            The project per location VPC SC policy that
            defines the VPC SC behavior for the Remote
            Repository (Allow/Deny).
    """

    class VPCSCPolicy(proto.Enum):
        r"""VPCSCPolicy is the VPC SC policy for project and location.

        Values:
            VPCSC_POLICY_UNSPECIFIED (0):
                VPCSC_POLICY_UNSPECIFIED - the VPS SC policy is not defined.
                When VPS SC policy is not defined - the Service will use the
                default behavior (VPCSC_DENY).
            DENY (1):
                VPCSC_DENY - repository will block the requests to the
                Upstreams for the Remote Repositories if the resource is in
                the perimeter.
            ALLOW (2):
                VPCSC_ALLOW - repository will allow the requests to the
                Upstreams for the Remote Repositories if the resource is in
                the perimeter.
        """
        VPCSC_POLICY_UNSPECIFIED = 0
        DENY = 1
        ALLOW = 2

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    vpcsc_policy: VPCSCPolicy = proto.Field(
        proto.ENUM,
        number=2,
        enum=VPCSCPolicy,
    )


class GetVPCSCConfigRequest(proto.Message):
    r"""Gets the VPC SC config for a project.

    Attributes:
        name (str):
            Required. The name of the VPCSCConfig
            resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateVPCSCConfigRequest(proto.Message):
    r"""Sets the VPCSC config of the project.

    Attributes:
        vpcsc_config (google.cloud.artifactregistry_v1.types.VPCSCConfig):
            The project config.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Field mask to support partial updates.
    """

    vpcsc_config: "VPCSCConfig" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="VPCSCConfig",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import struct_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.artifactregistry_v1.types import file, tag

__protobuf__ = proto.module(
    package="google.devtools.artifactregistry.v1",
    manifest={
        "VersionView",
        "Version",
        "ListVersionsRequest",
        "ListVersionsResponse",
        "GetVersionRequest",
        "DeleteVersionRequest",
        "BatchDeleteVersionsRequest",
        "BatchDeleteVersionsMetadata",
        "UpdateVersionRequest",
    },
)


class VersionView(proto.Enum):
    r"""The view, which determines what version information is
    returned in a response.

    Values:
        VERSION_VIEW_UNSPECIFIED (0):
            The default / unset value.
            The API will default to the BASIC view.
        BASIC (1):
            Includes basic information about the version,
            but not any related tags.
        FULL (2):
            Include everything.
    """
    VERSION_VIEW_UNSPECIFIED = 0
    BASIC = 1
    FULL = 2


class Version(proto.Message):
    r"""The body of a version resource. A version resource represents
    a collection of components, such as files and other data. This
    may correspond to a version in many package management schemes.

    Attributes:
        name (str):
            The name of the version, for example:
            ``projects/p1/locations/us-central1/repositories/repo1/packages/pkg1/versions/art1``.
            If the package or version ID parts contain slashes, the
            slashes are escaped.
        description (str):
            Optional. Description of the version, as
            specified in its metadata.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            The time when the version was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            The time when the version was last updated.
        related_tags (MutableSequence[google.cloud.artifactregistry_v1.types.Tag]):
            Output only. A list of related tags. Will
            contain up to 100 tags that reference this
            version.
        metadata (google.protobuf.struct_pb2.Struct):
            Output only. Repository-specific Metadata stored against
            this version. The fields returned are defined by the
            underlying repository-specific resource. Currently, the
            resources could be:
            [DockerImage][google.devtools.artifactregistry.v1.DockerImage]
            [MavenArtifact][google.devtools.artifactregistry.v1.MavenArtifact]
        annotations (MutableMapping[str, str]):
            Optional. Client specified annotations.
        fingerprints (MutableSequence[google.cloud.artifactregistry_v1.types.Hash]):
            Output only. Immutable reference for the version, calculated
            based on the version's content. Currently we only support
            dirsum_sha256 hash algorithm. Additional hash algorithms may
            be added in the future.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    description: str = proto.Field(
        proto.STRING,
        number=3,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    related_tags: MutableSequence[tag.Tag] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message=tag.Tag,
    )
    metadata: struct_pb2.Struct = proto.Field(
        proto.MESSAGE,
        number=8,
        message=struct_pb2.Struct,
    )
    annotations: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=9,
    )
    fingerprints: MutableSequence[file.Hash] = proto.RepeatedField(
        proto.MESSAGE,
        number=10,
        message=file.Hash,
    )


class ListVersionsRequest(proto.Message):
    r"""The request to list versions.

    Attributes:
        parent (str):
            The name of the parent resource whose
            versions will be listed.
        page_size (int):
            The maximum number of versions to return.
            Maximum page size is 1,000.
        page_token (str):
            The next_page_token value returned from a previous list
            request, if any.
        view (google.cloud.artifactregistry_v1.types.VersionView):
            The view that should be returned in the
            response.
        order_by (str):
            Optional. The field to order the results by.
        filter (str):
            Optional. An expression for filtering the results of the
            request. Filter rules are case insensitive. The fields
            eligible for filtering are:

            - ``name``
            - ``annotations``

            Examples of using a filter:

            To filter the results of your request to versions with the
            name ``my-version`` in project ``my-project`` in the
            ``us-central`` region, in repository ``my-repo``, append the
            following filter expression to your request:

            - ``name="projects/my-project/locations/us-central1/repositories/my-repo/packages/my-package/versions/my-version"``

            You can also use wildcards to match any number of characters
            before or after the value:

            - ``name="projects/my-project/locations/us-central1/repositories/my-repo/packages/my-package/versions/*version"``
            - ``name="projects/my-project/locations/us-central1/repositories/my-repo/packages/my-package/versions/my*"``
            - ``name="projects/my-project/locations/us-central1/repositories/my-repo/packages/my-package/versions/*version*"``

            To filter the results of your request to versions with the
            annotation key-value pair [``external_link``:
            ``external_link_value``], append the following filter
            expression to your request:

            - ``"annotations.external_link:external_link_value"``

            To filter just for a specific annotation key
            ``external_link``, append the following filter expression to
            your request:

            - ``"annotations.external_link"``

            If the annotation key or value contains special characters,
            you can escape them by surrounding the value with backticks.
            For example, to filter the results of your request to
            versions with the annotation key-value pair
            [``external.link``:``https://example.com/my-version``],
            append the following filter expression to your request:

            - :literal:`"annotations.`external.link\`:\`https://example.com/my-version\`"`

            You can also filter with annotations with a wildcard to
            match any number of characters before or after the value:

            - :literal:`"annotations.*_link:\`*example.com*\`"`
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    view: "VersionView" = proto.Field(
        proto.ENUM,
        number=4,
        enum="VersionView",
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=6,
    )


class ListVersionsResponse(proto.Message):
    r"""The response from listing versions.

    Attributes:
        versions (MutableSequence[google.cloud.artifactregistry_v1.types.Version]):
            The versions returned.
        next_page_token (str):
            The token to retrieve the next page of
            versions, or empty if there are no more versions
            to return.
    """

    @property
    def raw_page(self):
        return self

    versions: MutableSequence["Version"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Version",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetVersionRequest(proto.Message):
    r"""The request to retrieve a version.

    Attributes:
        name (str):
            The name of the version to retrieve.
        view (google.cloud.artifactregistry_v1.types.VersionView):
            The view that should be returned in the
            response.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    view: "VersionView" = proto.Field(
        proto.ENUM,
        number=2,
        enum="VersionView",
    )


class DeleteVersionRequest(proto.Message):
    r"""The request to delete a version.

    Attributes:
        name (str):
            The name of the version to delete.
        force (bool):
            By default, a version that is tagged may not
            be deleted. If force=true, the version and any
            tags pointing to the version are deleted.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    force: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class BatchDeleteVersionsRequest(proto.Message):
    r"""The request to delete multiple versions across a repository.

    Attributes:
        parent (str):
            The name of the repository holding all
            requested versions.
        names (MutableSequence[str]):
            Required. The names of the versions to
            delete. The maximum number of versions deleted
            per batch is determined by the service and is
            dependent on the available resources in the
            region.
        validate_only (bool):
            If true, the request is performed without
            deleting data, following AIP-163.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )
    validate_only: bool = proto.Field(
        proto.BOOL,
        number=3,
    )


class BatchDeleteVersionsMetadata(proto.Message):
    r"""The metadata of an LRO from deleting multiple versions.

    Attributes:
        failed_versions (MutableSequence[str]):
            The versions the operation failed to delete.
    """

    failed_versions: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class UpdateVersionRequest(proto.Message):
    r"""The request to update a version.

    Attributes:
        version (google.cloud.artifactregistry_v1.types.Version):
            Required. The Version that replaces the
            resource on the server.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The update mask applies to the resource. For the
            ``FieldMask`` definition, see
            https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
    """

    version: "Version" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Version",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.devtools.artifactregistry.v1beta2",
    manifest={
        "Hash",
        "File",
        "ListFilesRequest",
        "ListFilesResponse",
        "GetFileRequest",
    },
)


class Hash(proto.Message):
    r"""A hash of file content.

    Attributes:
        type_ (google.cloud.artifactregistry_v1beta2.types.Hash.HashType):
            The algorithm used to compute the hash value.
        value (bytes):
            The hash value.
    """

    class HashType(proto.Enum):
        r"""The algorithm used to compute the hash.

        Values:
            HASH_TYPE_UNSPECIFIED (0):
                Unspecified.
            SHA256 (1):
                SHA256 hash.
            MD5 (2):
                MD5 hash.
        """
        HASH_TYPE_UNSPECIFIED = 0
        SHA256 = 1
        MD5 = 2

    type_: HashType = proto.Field(
        proto.ENUM,
        number=1,
        enum=HashType,
    )
    value: bytes = proto.Field(
        proto.BYTES,
        number=2,
    )


class File(proto.Message):
    r"""Files store content that is potentially associated with
    Packages or Versions.

    Attributes:
        name (str):
            The name of the file, for example:

            "projects/p1/locations/us-central1/repositories/repo1/files/a%2Fb%2Fc.txt".
            If the file ID part contains slashes, they are
            escaped.
        size_bytes (int):
            The size of the File in bytes.
        hashes (MutableSequence[google.cloud.artifactregistry_v1beta2.types.Hash]):
            The hashes of the file content.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            The time when the File was created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            The time when the File was last updated.
        owner (str):
            The name of the Package or Version that owns
            this file, if any.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    size_bytes: int = proto.Field(
        proto.INT64,
        number=3,
    )
    hashes: MutableSequence["Hash"] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message="Hash",
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    owner: str = proto.Field(
        proto.STRING,
        number=7,
    )


class ListFilesRequest(proto.Message):
    r"""The request to list files.

    Attributes:
        parent (str):
            The name of the repository whose files will
            be listed. For example:
            "projects/p1/locations/us-central1/repositories/repo1
        filter (str):
            An expression for filtering the results of the request.
            Filter rules are case insensitive. The fields eligible for
            filtering are:

            - ``name``
            - ``owner``

            An example of using a filter:

            - ``name="projects/p1/locations/us-central1/repositories/repo1/files/a/b/*"``
              --> Files with an ID starting with "a/b/".
            - ``owner="projects/p1/locations/us-central1/repositories/repo1/packages/pkg1/versions/1.0"``
              --> Files owned by the version ``1.0`` in package
              ``pkg1``.
        page_size (int):
            The maximum number of files to return.
        page_token (str):
            The next_page_token value returned from a previous list
            request, if any.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )


class ListFilesResponse(proto.Message):
    r"""The response from listing files.

    Attributes:
        files (MutableSequence[google.cloud.artifactregistry_v1beta2.types.File]):
            The files returned.
        next_page_token (str):
            The token to retrieve the next page of files,
            or empty if there are no more files to return.
    """

    @property
    def raw_page(self):
        return self

    files: MutableSequence["File"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="File",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )


class GetFileRequest(proto.Message):
    r"""The request to retrieve a file.

    Attributes:
        name (str):
            The name of the file to retrieve.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .apt_artifact import (
    AptArtifact,
    ImportAptArtifactsErrorInfo,
    ImportAptArtifactsGcsSource,
    ImportAptArtifactsMetadata,
    ImportAptArtifactsRequest,
    ImportAptArtifactsResponse,
)
from .artifact import (
    DockerImage,
    GetDockerImageRequest,
    GetMavenArtifactRequest,
    GetNpmPackageRequest,
    GetPythonPackageRequest,
    ImageManifest,
    ListDockerImagesRequest,
    ListDockerImagesResponse,
    ListMavenArtifactsRequest,
    ListMavenArtifactsResponse,
    ListNpmPackagesRequest,
    ListNpmPackagesResponse,
    ListPythonPackagesRequest,
    ListPythonPackagesResponse,
    MavenArtifact,
    NpmPackage,
    PythonPackage,
)
from .attachment import (
    Attachment,
    CreateAttachmentRequest,
    DeleteAttachmentRequest,
    GetAttachmentRequest,
    ListAttachmentsRequest,
    ListAttachmentsResponse,
)
from .export import (
    ExportArtifactMetadata,
    ExportArtifactRequest,
    ExportArtifactResponse,
)
from .file import (
    DeleteFileRequest,
    File,
    GetFileRequest,
    Hash,
    ListFilesRequest,
    ListFilesResponse,
    UpdateFileRequest,
)
from .generic import GenericArtifact
from .go import GoModule
from .kfp_artifact import KfpArtifact
from .package import (
    DeletePackageRequest,
    GetPackageRequest,
    ListPackagesRequest,
    ListPackagesResponse,
    Package,
    UpdatePackageRequest,
)
from .repository import (
    CleanupPolicy,
    CleanupPolicyCondition,
    CleanupPolicyMostRecentVersions,
    CreateRepositoryRequest,
    DeleteRepositoryRequest,
    GetRepositoryRequest,
    ListRepositoriesRequest,
    ListRepositoriesResponse,
    RemoteRepositoryConfig,
    Repository,
    UpdateRepositoryRequest,
    UpstreamPolicy,
    VirtualRepositoryConfig,
)
from .rule import (
    CreateRuleRequest,
    DeleteRuleRequest,
    GetRuleRequest,
    ListRulesRequest,
    ListRulesResponse,
    Rule,
    UpdateRuleRequest,
)
from .service import OperationMetadata
from .settings import (
    GetProjectSettingsRequest,
    ProjectSettings,
    UpdateProjectSettingsRequest,
)
from .tag import (
    CreateTagRequest,
    DeleteTagRequest,
    GetTagRequest,
    ListTagsRequest,
    ListTagsResponse,
    Tag,
    UpdateTagRequest,
)
from .version import (
    BatchDeleteVersionsMetadata,
    BatchDeleteVersionsRequest,
    DeleteVersionRequest,
    GetVersionRequest,
    ListVersionsRequest,
    ListVersionsResponse,
    UpdateVersionRequest,
    Version,
    VersionView,
)
from .vpcsc_config import GetVPCSCConfigRequest, UpdateVPCSCConfigRequest, VPCSCConfig
from .yum_artifact import (
    ImportYumArtifactsErrorInfo,
    ImportYumArtifactsGcsSource,
    ImportYumArtifactsMetadata,
    ImportYumArtifactsRequest,
    ImportYumArtifactsResponse,
    YumArtifact,
)

__all__ = (
    "AptArtifact",
    "ImportAptArtifactsErrorInfo",
    "ImportAptArtifactsGcsSource",
    "ImportAptArtifactsMetadata",
    "ImportAptArtifactsRequest",
    "ImportAptArtifactsResponse",
    "DockerImage",
    "GetDockerImageRequest",
    "GetMavenArtifactRequest",
    "GetNpmPackageRequest",
    "GetPythonPackageRequest",
    "ImageManifest",
    "ListDockerImagesRequest",
    "ListDockerImagesResponse",
    "ListMavenArtifactsRequest",
    "ListMavenArtifactsResponse",
    "ListNpmPackagesRequest",
    "ListNpmPackagesResponse",
    "ListPythonPackagesRequest",
    "ListPythonPackagesResponse",
    "MavenArtifact",
    "NpmPackage",
    "PythonPackage",
    "Attachment",
    "CreateAttachmentRequest",
    "DeleteAttachmentRequest",
    "GetAttachmentRequest",
    "ListAttachmentsRequest",
    "ListAttachmentsResponse",
    "ExportArtifactMetadata",
    "ExportArtifactRequest",
    "ExportArtifactResponse",
    "DeleteFileRequest",
    "File",
    "GetFileRequest",
    "Hash",
    "ListFilesRequest",
    "ListFilesResponse",
    "UpdateFileRequest",
    "GenericArtifact",
    "GoModule",
    "KfpArtifact",
    "DeletePackageRequest",
    "GetPackageRequest",
    "ListPackagesRequest",
    "ListPackagesResponse",
    "Package",
    "UpdatePackageRequest",
    "CleanupPolicy",
    "CleanupPolicyCondition",
    "CleanupPolicyMostRecentVersions",
    "CreateRepositoryRequest",
    "DeleteRepositoryRequest",
    "GetRepositoryRequest",
    "ListRepositoriesRequest",
    "ListRepositoriesResponse",
    "RemoteRepositoryConfig",
    "Repository",
    "UpdateRepositoryRequest",
    "UpstreamPolicy",
    "VirtualRepositoryConfig",
    "CreateRuleRequest",
    "DeleteRuleRequest",
    "GetRuleRequest",
    "ListRulesRequest",
    "ListRulesResponse",
    "Rule",
    "UpdateRuleRequest",
    "OperationMetadata",
    "GetProjectSettingsRequest",
    "ProjectSettings",
    "UpdateProjectSettingsRequest",
    "CreateTagRequest",
    "DeleteTagRequest",
    "GetTagRequest",
    "ListTagsRequest",
    "ListTagsResponse",
    "Tag",
    "UpdateTagRequest",
    "BatchDeleteVersionsMetadata",
    "BatchDeleteVersionsRequest",
    "DeleteVersionRequest",
    "GetVersionRequest",
    "ListVersionsRequest",
    "ListVersionsResponse",
    "UpdateVersionRequest",
    "Version",
    "VersionView",
    "GetVPCSCConfigRequest",
    "UpdateVPCSCConfigRequest",
    "VPCSCConfig",
    "ImportYumArtifactsErrorInfo",
    "ImportYumArtifactsGcsSource",
    "ImportYumArtifactsMetadata",
    "ImportYumArtifactsRequest",
    "ImportYumArtifactsResponse",
    "YumArtifact",
)
